/*
 * Copyright 2018 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.ide.visualstudio;

import org.gradle.api.Action;

/**
 * The configuration for mapping a set of native components to a Visual Studio project and solution.
 *
 * @since 4.6
 */
public interface VisualStudioRootExtension extends VisualStudioExtension {
    /**
     * Returns the generated  {@link VisualStudioSolution} for this build.
     */
    VisualStudioSolution getSolution();

    /**
     * Configures the generated {@link VisualStudioSolution} for this build.
     */
    void solution(Action<? super VisualStudioSolution> configAction);
}
