/*
 * Copyright 2020 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.kotlin.dsl.provider


object KotlinDslPluginSupport {

    val kotlinCompilerArgs: List<String>
        get() = listOf(
            "-java-parameters",
            "-Xjvm-default=all",
            "-Xjsr305=strict",
            "-Xjspecify-annotations=strict",
            "-Xsam-conversions=class",
            "-Xuse-fir-lt=false",
        )
}
