/*
 * Copyright 2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.problems.internal;

import org.jspecify.annotations.Nullable;

public class ProblemsProgressEventEmitterHolder {

    @Nullable
    private static ProblemsInternal problemsService = null;

    public static void init(ProblemsInternal problemsService) {
        ProblemsProgressEventEmitterHolder.problemsService = problemsService;
    }

    public static void clear() {
        problemsService = null;
    }

    public static ProblemsInternal get() {
        if (problemsService == null) {
            throw new IllegalStateException("Problems service is not initialized.");
        }
        return problemsService;
    }
}
